export const defaultSelectedColumnIds = [
  'name',
  'alias',
  'enabled_hosts_count',
  'disabled_hosts_count',
  'actions',
  'is_activated'
];

export const filtersInitialValues = {
  name: '',
  alias: '',
  enabled: false,
  disabled: false
};

export const filtersAtomKey = 'filters_hostgroups';
export const columnsAtomKey = 'columns_hostgroups';
